package com.ruoyi.mall.mapper;

import com.ruoyi.mall.domain.MallConfig;
import com.ruoyi.mall.domain.Vo.ExplainConfigVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 配置Mapper接口
 *
 * @author ruoyi
 * @date 2023-10-09
 */
public interface MallConfigMapper
{
    /**
     * 查询配置
     *
     * @param id 配置主键
     * @return 配置
     */
    public MallConfig selectMallConfigById(Long id);

    /**
     * 查询配置列表
     *
     * @param mallConfig 配置
     * @return 配置集合
     */
    public List<MallConfig> selectMallConfigList(MallConfig mallConfig);

    /**
     * 新增配置
     *
     * @param mallConfig 配置
     * @return 结果
     */
    public int insertMallConfig(MallConfig mallConfig);

    /**
     * 修改配置
     *
     * @param mallConfig 配置
     * @return 结果
     */
    public int updateMallConfig(MallConfig mallConfig);

    /**
     * 删除配置
     *
     * @param id 配置主键
     * @return 结果
     */
    public int deleteMallConfigById(Long id);

    /**
     * 批量删除配置
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallConfigByIds(Long[] ids);

    /**
     * 根据标识查询配置
     *
     * @param mark 标识
     * @return 配置
     */
    public MallConfig selectMallConfigByMarK(String mark);

    /**
     * 根据标记查询说明配置
     * @param mark 标记
     * @return 结果
     */
    public ExplainConfigVO selectExplainConfig(@Param("mark") String mark);
}
