package com.ruoyi.mall.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.mall.domain.MallConfig;
import com.ruoyi.mall.service.*;
import com.ruoyi.system.domain.SysUserRole;
import com.ruoyi.system.mapper.SysUserRoleMapper;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 配置Controller
 *
 * @author ruoyi
 * @date 2023-10-09
 */
@RestController
@RequestMapping("/mall/config")
public class MallConfigController extends BaseController
{
    @Resource
    private IMallConfigService mallConfigService;

    /**
     * 查询配置列表
     */
    @PreAuthorize("@ss.hasPermi('mall:config:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallConfig mallConfig)
    {
        startPage();
        List<MallConfig> list = mallConfigService.selectMallConfigList(mallConfig);
        return getDataTable(list);
    }

    /**
     * 导出配置列表
     */
    @PreAuthorize("@ss.hasPermi('mall:config:export')")
    @Log(title = "配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MallConfig mallConfig)
    {
        List<MallConfig> list = mallConfigService.selectMallConfigList(mallConfig);
        ExcelUtil<MallConfig> util = new ExcelUtil<MallConfig>(MallConfig.class);
        util.exportExcel(response, list, "配置数据");
    }

    /**
     * 获取配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:config:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(mallConfigService.selectMallConfigById(id));
    }

    /**
     * 新增配置
     */
    @PreAuthorize("@ss.hasPermi('mall:config:add')")
    @Log(title = "配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallConfig mallConfig)
    {
        mallConfig.setCreateAt(DateUtils.getTime());
        return toAjax(mallConfigService.insertMallConfig(mallConfig));
    }

    /**
     * 修改配置
     */
    @PreAuthorize("@ss.hasPermi('mall:config:edit')")
    @Log(title = "配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallConfig mallConfig)
    {
        return toAjax(mallConfigService.updateMallConfig(mallConfig));
    }

    /**
     * 删除配置
     */
    @PreAuthorize("@ss.hasPermi('mall:config:remove')")
    @Log(title = "配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallConfigService.deleteMallConfigByIds(ids));
    }
}
